@@ -16,12 +16,13 @@ class SemanticParser : public QObject
 public:
     explicit SemanticParser(QObject *parent = nullptr);
     ~SemanticParser();
-    bool connectToAnalyze(const QString &service);
     bool connectToVector(const QString &service);
+    bool connectToQueryLang(const QString &service);
     QString analyze(const QString &text);
     QString vectorSearch(const QString &prompt);
-    bool isAnalayzeSupported();
+    QString query(const QString &text);
     bool isVectorSupported();
+    bool isQueryLangSupported();
 public slots:
 private:
     SemanticParserPrivate *d;
